Welcome to ClientVPS Mirrors

Help for package PROBShiny
Type: Package
Title: Interactive Document for Working with Basic Probability
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: An interactive document on the topic of basic probability using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at https://analyticmodels.shinyapps.io/BayesShiny/.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,rmarkdown,LaplacesDemon,shinyMatrix,rpivotTable,epitools
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2019-04-18 17:10:53 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2019-04-23 08:30:03 UTC

Launch 'PROBShiny' Interface

Description

PROBShiny() loads interactive user interface built using R 'shiny'.

Usage

PROBShiny()

Details

Start PROBShiny

The interactive user interface is to provide an easy way for solving basic probability problems based on relative frequency and subjective approach.

Value

Nothing

Examples

if(interactive()){
library(rmarkdown)
PROBShiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.